**[Download Latest PDF](https://i10git.cs.fau.de/da15siwa/lssthesis-memoir/-/jobs/artifacts/master/raw/out/thesis.pdf?job=compile)**

# lssthesis-memoir

Template for student theses written in LaTeX at LSS, based on the memoir document class.

This repository contains a template for bachelor's and master's thesis written at the Chair for System Simulation at FAU, based on the memoir document class ([https://ctan.org/pkg/memoir](https://ctan.org/pkg/memoir)) and the *lsspub* template. This template consists of the *lsspub-memoir* document class ([includes/lsspub-memoir.cls](includes/lsspub-memoir.cls)), a sample document structure, and a *Makefile* defining a build system for modular and reproducible thesis building from scratch.

# Build System

## Overview

Contained in this repository is a *make*-based build system constructed for incremental building of your thesis. In this system, measures have been taken to only rebuild those parts of your document that actually have changed. The entire document can simply be built by running the command `make thesis` in the root directory. For the main document, as well as for individual chapters, it uses [latexmk](https://ctan.org/pkg/latexmk), which runs `pdflatex` (or, if desired, `luatex`) together with `bibtex` (or, in our case, `biber`) as many times as necessary to construct a PDF file from your document sources. All output files are written to an `out` folder. Any output files may be removed by calling `make clean`. Apart from building the entire thesis, the system also supports building individual chapters by calling `make chapterX`, provided a standalone file `chapterX.tex` is present in the root folder. Simply calling `make` without further arguments causes all standalone chapters and the thesis to be built.

##  Standalone Chapters

The Makefile contains the option to build single chapters individually. For this, both a file `chapterX.tex` must be present in the root directory, and the target `chapterX` must be added to the bottom of the Makefile, with any required dependencies.
## Standalone and Python-Generated Pictures

LaTeX theses are seldom monolithic; they contain pictures, diagrams, plots and tables of many a kind. Some of these are static; they may simply be saved alongside the `.tex` files and included into the document. But very often, such pictures are dynamically generated from raw data using scripts. Furthermore, many pictures and diagrams can be written in [TikZ](https://www.ctan.org/pkg/pgf) (a very powerful graphics package for LaTeX, check it out!), which may be done directly within the main LaTeX document. However, such graphics will often take a long time to build, slowing down typesetting of the entire document even if they were not changed. Also, when creating them, having to build the entire document if you are just interested in getting a single picture right is also very annoying. The solution is to set your TikZ pictures in *standalone* LaTeX documents, which translate to an individual PDF file for each picture, which may then be included into your main document using `\includegraphics`.

Building of dynamically generated external files should not be left to the user (in this case, you), to make sure they are always reproducable and up-to-date. Hence, this repository offers a few tools to automate this process. The *Makefile* of this repository contains code to build standalone TikZ-pictures and any standalone `.tex` files generated from Python scripts automatically, and only if their sources have changed. This works in the following way:

### Standalone LaTeX / TikZ Pics

The Makefile treats every `.tex` file in the `pics` subfolder as a source for a standalone picture. It calls `pdflatex` for every such file, and writes the generated PDF file to `pics/out`. Hence, any picture generated this way must be included in the main document from the `pics/out`-folder. Example: The file [SpheresInBox2D.tex](pics/SpheresInBox2D.tex) in this template will be compiled to `pics/out/SpheresInBox2D.pdf` which must be included using `\includegraphics{pics/out/SpheresInBox2D.tex}`.

### Python-Generated LaTeX code

The Makefile searches the subfolder `py2tex` for Python scripts, which are expected to generate a `.tex` file in `py2tex/out` with the same name as the script.
These files are then compiled using `pdflatex`. This may for example be used to automatically build script-generated tables
or [matplotlib](https://matplotlib.org/)-generated graphs.
For example, the script `py2tex/WildGrowthOfSpheres.py` of this template uses matplotlib to generate a graph,
which is exported as pgfplots code to `py2tex/out/WildGrowthOfSpheres.tex`, which is then rendered to `py2tex/out/WildGrowthOfSpheres.pdf`.
This file can then be included into the LaTeX document using `\includegraphics{py2tex/out/WildGrowthOfSpheres.pdf}`.

## To Makefile or not To Makefile?

It is recommended that noone should just use some Makefile from the internet without understanding what it does. You should hence take a few minutes and familiarize yourself with the inner workings of the Makefile. It is not meant as a final solution, but as a starting point for anyone wanting to reliably build their thesis, ready to be extended for individual needs. If you do not feel confident with using this Makefile, but still employ techniques for incremental and reliable document building (which is highly recommended!), you might be better off setting up your own Makefile from scratch. Advice for combining LaTeX with `make` can be found on the internet.

# Repository Details
### Authors:

**lsspub-memoir + Build Infrastructure:**
 * Frederik Hennig ([frederik.hennig@fau.de](mailto:frederik.hennig@fau.de))

based on
**LaTeX style for LSS publications (lsspub.sty, v1.2):**
 * Markus Stürmer
 * Matthias Hofmann
 * Markus Holzer

based on
**LaTeX-Style for Thesis-Titelblatt:**
 * Marcus Mohr

### Version History:

 * **v1.1 - July 12, 2024:**
   - Remove `tikzplotlib` since it is no longer being developed and matplotlib's own PGF exporter is now working perfectly
   - Fix centering of front page
   - Move "lists of ..." to the end of the document
   - Fix layout of the front matter
   - Change default chapter style to `madsen`
   - Add sample appendix and bibliography

 * **April 20, 2024:** 
   - Update dockerfile and Python dependencies
   - Use latin modern fonts instead of computer modern (TeXLive seems to no longer support the latter)
 
 * **v1.0 - October 2021:** Template clean-up and documentation of structure and build system
