import numpy as np
import matplotlib.pyplot as plt
from util.latex import export_figure

from os import path

OUTDIR = "out"

SCRIPT_FILENAME = path.split(__file__)[1]
OUTPUT_FILENAME = path.join(OUTDIR, path.splitext(SCRIPT_FILENAME)[0] + ".tex")

LSSBLUE = (0.121,0.231,0.4)
LSSRED = (0.76,0.3,0.19)
LSSGREEN = "#1F6622"

cm = 1/2.54
W, H = 13, 5

TIKZPLOT_PARAMS = {
    'standalone' : True,
    'strict': True,
    'extra_axis_parameters' : ["scaled x ticks=false", "scaled y ticks=false"],
    'axis_width': f"{W}cm",
    'axis_height': f"{H}cm",
}

fig, ax = plt.subplots(figsize=(W*cm, H*cm))

ns = np.arange(1, 13, step=1)
radii = np.sqrt(ns) - 1

ax.grid()
ax.set_xlabel(r'$n$')
ax.set_ylabel(r'$s$')

ax.plot(ns, radii, marker='s', color=LSSRED, lw=0.5, markersize=4)

fig.tight_layout()

export_figure(fig)
